:mod:`oujago.nlp.srl`
=====================

.. automodule:: oujago.nlp.srl

.. autosummary::

    BaseSRL
    LTPSRL
    srlabel


Detailed Description
--------------------


.. autoclass:: BaseSRL
    :members:


.. autoclass:: LTPSRL
    :members:

.. autofunction:: srlabel
